Documentation
¶
Overview ¶
Package booking API.
the purpose of this application is to provide an application that is using plain go code to define an API
Schemes: https Host: localhost Version: 0.0.1 Consumes: - application/json Produces: - application/json
swagger:meta
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BookingResponse ¶
type BookingResponse struct {
// Booking struct
//
// in: body
// required: true
Body struct {
Booking makeplans.Booking `json:"booking"`
Customer Customer `json:"customer"`
Dates DateRange `json:"dates"`
}
}
BookingResponse represents a scheduled appointment
swagger:response BookingResponse
type Customer ¶ added in v0.17.0
type Customer struct {
Name string `json:"name"`
}
Customer of the site.
swagger:model Customer
Click to show internal directories.
Click to hide internal directories.